@@ -15,8 +15,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import click
+import os
 
-from snapcraft.internal import lifecycle
+import snapcraft
+from snapcraft.internal import deprecations, lifecycle, lxd
 from ._options import add_build_options, get_project_options
 from . import echo
 from . import env
@@ -24,9 +26,10 @@ from . import env
 
 def _execute(command, parts, **kwargs):
     project_options = get_project_options(**kwargs)
-
-    if env.is_containerbuild():
-        lifecycle.containerbuild(command, project_options, parts)
+    container_config = env.get_container_config()
+    if container_config.use_container:
+        lifecycle.containerbuild(command, project_options,
+                                 container_config, parts)
     else:
         lifecycle.execute(command, project_options, parts)
     return project_options
@@ -121,18 +124,42 @@ def snap(directory, output, **kwargs):
         snapcraft snap
         snapcraft snap --output renamed-snap.snap
 
-    If you want to snap a directory, you should use the snap-dir command
+    If you want to snap a directory, you should use the pack command
     instead.
     """
+    if directory:
+        deprecations.handle_deprecation_notice('dn6')
+
     project_options = get_project_options(**kwargs)
-    if env.is_containerbuild():
-        lifecycle.containerbuild('snap', project_options, output, directory)
+    container_config = env.get_container_config()
+    if container_config.use_container:
+        lifecycle.containerbuild('snap', project_options,
+                                 container_config, output, directory)
     else:
         snap_name = lifecycle.snap(
             project_options, directory=directory, output=output)
         echo.info('Snapped {}'.format(snap_name))
 
 
+@lifecyclecli.command()
+@click.argument('directory')
+@click.option('--output', '-o', help='path to the resulting snap.')
+def pack(directory, output, **kwargs):
+    """Create a snap from a directory holding a valid snap.
+
+    The layout of <directory> should contain a valid meta/snap.yaml in
+    order to be a valid snap.
+
+    \b
+    Examples:
+        snapcraft pack my-snap-directory
+        snapcraft pack my-snap-directory --output renamed-snap.snap
+
+    """
+    snap_name = lifecycle.pack(directory, output)
+    echo.info('Snapped {}'.format(snap_name))
+
+
 @lifecyclecli.command()
 @add_build_options()
 @click.argument('parts', nargs=-1, metavar='<part>...', required=False)
@@ -149,11 +176,15 @@ def clean(parts, step, **kwargs):
         snapcraft clean my-part --step build
     """
     project_options = get_project_options(**kwargs)
-    if env.is_containerbuild():
-        step = step or 'pull'
-        lifecycle.containerbuild('clean', project_options,
-                                 args=['--step', step, *parts])
+    container_config = env.get_container_config()
+    if container_config.use_container:
+        config = snapcraft.internal.load_config(project_options)
+        lxd.Project(project_options=project_options,
+                    remote=container_config.remote,
+                    output=None, source=os.path.curdir,
+                    metadata=config.get_metadata()).clean(parts, step)
     else:
+        step = step or 'pull'
         if step == 'strip':
             echo.warning('DEPRECATED: Use `prime` instead of `strip` '
                          'as the step to clean')
