@@ -15,8 +15,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import copy
+import collections
 import contextlib
 import configparser
+import json
 import logging
 import os
 import re
@@ -46,22 +48,23 @@ logger = logging.getLogger(__name__)
 
 _MANDATORY_PACKAGE_KEYS = [
     'name',
-    'description',
+    'version',
     'summary',
+    'description',
 ]
 
 _OPTIONAL_PACKAGE_KEYS = [
-    'architectures',
-    'assumes',
-    'base',
-    'environment',
     'type',
+    'base',
+    'architectures',
+    'confinement',
+    'grade',
+    'assumes',
     'plugs',
     'slots',
-    'confinement',
     'epoch',
-    'grade',
     'hooks',
+    'environment',
 ]
 
 
@@ -155,11 +158,21 @@ class _SnapPackaging:
             annotated_snapcraft = self._annotate_snapcraft(
                 copy.deepcopy(self._config_data))
             with open(manifest_file_path, 'w') as manifest_file:
-                yaml.dump(annotated_snapcraft, manifest_file)
+                yaml.dump(
+                    annotated_snapcraft, manifest_file,
+                    default_flow_style=False)
 
     def _annotate_snapcraft(self, data):
-        data['build-packages'] = get_global_state().assets.get(
-            'build-packages', [])
+        image_info = os.environ.get('SNAPCRAFT_IMAGE_INFO')
+        if image_info:
+            try:
+                image_info_dict = json.loads(image_info)
+            except json.decoder.JSONDecodeError as exception:
+                raise errors.InvalidContainerImageInfoError(
+                    image_info) from exception
+            data['image-info'] = image_info_dict
+        for field in ('build-packages', 'build-snaps'):
+            data[field] = get_global_state().assets.get(field, [])
         for part in data['parts']:
             state_dir = os.path.join(self._parts_dir, part, 'state')
             pull_state = get_state(state_dir, 'pull')
@@ -258,11 +271,12 @@ class _SnapPackaging:
 
         Keys that are in _OPTIONAL_PACKAGE_KEYS are ignored if not there.
         """
-        snap_yaml = {}
+        snap_yaml = collections.OrderedDict()
 
         for key_name in _MANDATORY_PACKAGE_KEYS:
             snap_yaml[key_name] = self._config_data[key_name]
 
+        # Reparse the version, the order should stick.
         snap_yaml['version'] = self._get_version(
             self._config_data['version'],
             self._config_data.get('version-script'))
@@ -303,7 +317,11 @@ class _SnapPackaging:
 
     def _write_wrap_exe(self, wrapexec, wrappath,
                         shebang=None, args=None, cwd=None):
-        args = ' '.join(args) + ' "$@"' if args else '"$@"'
+        if args:
+            quoted_args = ['"{}"'.format(arg) for arg in args]
+        else:
+            quoted_args = []
+        args = ' '.join(quoted_args) + ' "$@"' if args else '"$@"'
         cwd = 'cd {}'.format(cwd) if cwd else ''
 
         # If we are dealing with classic confinement it means all our
@@ -382,7 +400,10 @@ class _SnapPackaging:
             if os.path.splitext(f)[1] == '.desktop':
                 os.remove(os.path.join(gui_dir, f))
         for app in apps:
-            self._wrap_app(app, apps[app])
+            adapter = apps[app].get('adapter', '')
+            if adapter != 'none':
+                self._wrap_app(app, apps[app])
+            self._generate_desktop_file(app, apps[app])
         return apps
 
     def _wrap_app(self, name, app):
@@ -392,6 +413,8 @@ class _SnapPackaging:
                 app[k] = self._wrap_exe(app[k], '{}-{}'.format(k, name))
             except CommandError as e:
                 raise errors.InvalidAppCommandError(str(e), name)
+
+    def _generate_desktop_file(self, name, app):
         desktop_file_name = app.pop('desktop', '')
         if desktop_file_name:
             desktop_file = _DesktopFile(
