@@ -1,6 +1,6 @@
 # -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
 #
-# Copyright (C) 2016 Canonical Ltd
+# Copyright (C) 2016-2017 Canonical Ltd
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3 as
@@ -14,11 +14,30 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import os
 import yaml
 
 
 class State(yaml.YAMLObject):
+
+    def __repr__(self):
+        items = sorted(self.__dict__.items())
+        strings = (': '.join((key, repr(value))) for key, value in items)
+        representation = ', '.join(strings)
+
+        return '{}({})'.format(self.__class__.__name__, representation)
+
+    def __eq__(self, other):
+        if type(other) is type(self):
+            return self.__dict__ == other.__dict__
+
+        return False
+
+
+class PartState(State):
+
     def __init__(self, part_properties, project):
+        super().__init__()
         if not part_properties:
             part_properties = {}
 
@@ -51,19 +70,6 @@ class State(yaml.YAMLObject):
             self.project_options, self.project_options_of_interest(
                 other_project_options))
 
-    def __repr__(self):
-        items = sorted(self.__dict__.items())
-        strings = (': '.join((key, repr(value))) for key, value in items)
-        representation = ', '.join(strings)
-
-        return '{}({})'.format(self.__class__.__name__, representation)
-
-    def __eq__(self, other):
-        if type(other) is type(self):
-            return self.__dict__ == other.__dict__
-
-        return False
-
 
 def _get_differing_keys(dict1, dict2):
     differing_keys = set()
@@ -78,3 +84,22 @@ def _get_differing_keys(dict1, dict2):
             differing_keys.add(key)
 
     return differing_keys
+
+
+def get_global_state():
+    with open(os.path.join('snap', '.snapcraft', 'state'), 'r') as state_file:
+        return yaml.load(state_file)
+
+
+def get_state(state_dir, step):
+    state = None
+    state_file = get_step_state_file(state_dir, step)
+    if os.path.isfile(state_file):
+        with open(state_file, 'r') as f:
+            state = yaml.load(f.read())
+
+    return state
+
+
+def get_step_state_file(state_dir, step):
+    return os.path.join(state_dir, step)
