@@ -1,4 +1,3 @@
-
 # -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
 #
 # Copyright (C) 2016-2017 Canonical Ltd
@@ -41,12 +40,10 @@ from simplejson.scanner import JSONDecodeError
 import snapcraft
 from snapcraft import config
 from snapcraft.internal.indicators import download_requests_stream
-from snapcraft.storeapi import (
-    _agent,
-    _upload,
-    constants,
-    errors,
-)
+from . import _agent
+from . import _upload
+from . import constants
+from . import errors
 
 
 logger = logging.getLogger(__name__)
@@ -358,8 +355,8 @@ class StoreClient():
                 file_sum.update(file_chunk)
         return expected_sha512 == file_sum.hexdigest()
 
-    def push_assertion(self, snap_id, assertion, endpoint):
-        return self.sca.push_assertion(snap_id, assertion, endpoint)
+    def push_assertion(self, snap_id, assertion, endpoint, force=False):
+        return self.sca.push_assertion(snap_id, assertion, endpoint, force)
 
     def get_assertion(self, snap_id, endpoint):
         return self.sca.get_assertion(snap_id, endpoint)
@@ -633,7 +630,7 @@ class SCAClient(Client):
 
         return response_json
 
-    def push_assertion(self, snap_id, assertion, endpoint):
+    def push_assertion(self, snap_id, assertion, endpoint, force):
         if endpoint == 'validations':
             data = {
                 'assertion': assertion.decode('utf-8'),
@@ -643,11 +640,20 @@ class SCAClient(Client):
                 'snap_developer': assertion.decode('utf-8'),
             }
         auth = _macaroon_auth(self.conf)
+
+        url = 'snaps/{}/{}'.format(snap_id, endpoint)
+
+        # For `snap-developer`, revoking developers will require their uploads
+        # to be invalidated.
+        if force:
+            url = url + '?ignore_revoked_uploads'
+
         response = self.put(
-            'snaps/{}/{}'.format(snap_id, endpoint), data=json.dumps(data),
+            url, data=json.dumps(data),
             headers={'Authorization': auth,
                      'Content-Type': 'application/json',
                      'Accept': 'application/json'})
+
         if not response.ok:
             raise errors.StoreValidationError(snap_id, response)
         try:
