@@ -1078,7 +1078,7 @@ ACCEPT=n
         plugin.pull()
 
         download_mock.assert_called_once_with(
-            'ubuntu-core', 'edge', plugin.os_snap,
+            'core', 'stable', plugin.os_snap,
             self.project_options.deb_arch, '')
 
 
