@@ -14,9 +14,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import collections
 import os
 
 from unittest import mock
+from testscenarios.scenarios import multiply_scenarios
 from testtools.matchers import DirExists, Equals, HasLength
 
 import snapcraft
@@ -30,6 +32,15 @@ class NodePluginBaseTestCase(tests.TestCase):
     def setUp(self):
         super().setUp()
 
+        class Options:
+            source = '.'
+            node_packages = []
+            node_engine = nodejs._NODEJS_VERSION
+            npm_run = []
+            node_package_manager = 'npm'
+            source = '.'
+        self.options = Options()
+
         self.project_options = snapcraft.ProjectOptions()
 
         self.useFixture(tests.fixture_setup.CleanEnvironment())
@@ -38,6 +49,11 @@ class NodePluginBaseTestCase(tests.TestCase):
         self.run_mock = patcher.start()
         self.addCleanup(patcher.stop)
 
+        patcher = mock.patch('snapcraft.internal.common.run_output')
+        self.run_output_mock = patcher.start()
+        self.addCleanup(patcher.stop)
+        self.run_output_mock.return_value = '{"dependencies": []}'
+
         patcher = mock.patch('snapcraft.sources.Tar')
         self.tar_mock = patcher.start()
         self.addCleanup(patcher.stop)
@@ -58,15 +74,9 @@ class NodePluginTestCase(NodePluginBaseTestCase):
     ]
 
     def test_pull_local_sources(self):
-        class Options:
-            source = '.'
-            node_packages = []
-            node_engine = nodejs._NODEJS_VERSION
-            npm_run = []
-            node_package_manager = self.package_manager
-            source = '.'
+        self.options.node_package_manager = self.package_manager
 
-        plugin = nodejs.NodePlugin('test-part', Options(),
+        plugin = nodejs.NodePlugin('test-part', self.options,
                                    self.project_options)
 
         os.makedirs(plugin.sourcedir)
@@ -97,17 +107,11 @@ class NodePluginTestCase(NodePluginBaseTestCase):
         self.tar_mock.assert_has_calls(expected_tar_calls)
 
     def test_build_local_sources(self):
-        class Options:
-            source = '.'
-            node_packages = []
-            node_engine = nodejs._NODEJS_VERSION
-            npm_run = []
-            node_package_manager = self.package_manager
-            source = '.'
+        self.options.node_package_manager = self.package_manager
 
         open('package.json', 'w').close()
 
-        plugin = nodejs.NodePlugin('test-part', Options(),
+        plugin = nodejs.NodePlugin('test-part', self.options,
                                    self.project_options)
 
         os.makedirs(plugin.builddir)
@@ -150,15 +154,10 @@ class NodePluginTestCase(NodePluginBaseTestCase):
         self.tar_mock.assert_has_calls(expected_tar_calls)
 
     def test_pull_and_build_node_packages_sources(self):
-        class Options:
-            source = None
-            node_packages = ['my-pkg']
-            node_engine = nodejs._NODEJS_VERSION
-            npm_run = []
-            node_package_manager = self.package_manager
-            source = '.'
+        self.options.node_packages = ['my-pkg']
+        self.options.node_package_manager = self.package_manager
 
-        plugin = nodejs.NodePlugin('test-part', Options(),
+        plugin = nodejs.NodePlugin('test-part', self.options,
                                    self.project_options)
 
         os.makedirs(plugin.sourcedir)
@@ -210,15 +209,10 @@ class NodePluginTestCase(NodePluginBaseTestCase):
         self.tar_mock.assert_has_calls(expected_tar_calls)
 
     def test_pull_executes_npm_run_commands(self):
-        class Options:
-            source = '.'
-            node_packages = []
-            node_engine = '4'
-            npm_run = ['command_one', 'avocado']
-            node_package_manager = self.package_manager
-            source = '.'
+        self.options.npm_run = ['command_one', 'avocado']
+        self.options.node_package_manager = self.package_manager
 
-        plugin = nodejs.NodePlugin('test-part', Options(),
+        plugin = nodejs.NodePlugin('test-part', self.options,
                                    self.project_options)
 
         os.makedirs(plugin.sourcedir)
@@ -250,15 +244,10 @@ class NodePluginTestCase(NodePluginBaseTestCase):
         self.run_mock.assert_has_calls(expected_run_calls)
 
     def test_build_executes_npm_run_commands(self):
-        class Options:
-            source = '.'
-            node_packages = []
-            node_engine = '4'
-            npm_run = ['command_one', 'avocado']
-            node_package_manager = self.package_manager
-            source = '.'
+        self.options.npm_run = ['command_one', 'avocado']
+        self.options.node_package_manager = self.package_manager
 
-        plugin = nodejs.NodePlugin('test-part', Options(),
+        plugin = nodejs.NodePlugin('test-part', self.options,
                                    self.project_options)
 
         os.makedirs(plugin.sourcedir)
@@ -287,18 +276,12 @@ class NodePluginTestCase(NodePluginBaseTestCase):
 
     @mock.patch('snapcraft.ProjectOptions.deb_arch', 'fantasy-arch')
     def test_unsupported_arch_raises_exception(self):
-        class Options:
-            source = None
-            node_packages = []
-            node_engine = '4'
-            npm_run = []
-            node_package_manager = self.package_manager
-            source = '.'
+        self.options.node_package_manager = self.package_manager
 
         raised = self.assertRaises(
             errors.SnapcraftEnvironmentError,
             nodejs.NodePlugin,
-            'test-part', Options(),
+            'test-part', self.options,
             self.project_options)
 
         self.assertThat(raised.__str__(),
@@ -325,14 +308,9 @@ class NodePluginTestCase(NodePluginBaseTestCase):
             self.assertIn(property, resulting_pull_properties)
 
     def test_clean_pull_step(self):
-        class Options:
-            source = '.'
-            node_packages = []
-            node_engine = '4'
-            npm_run = []
-            node_package_manager = self.package_manager
+        self.options.node_package_manager = self.package_manager
 
-        plugin = nodejs.NodePlugin('test-part', Options(),
+        plugin = nodejs.NodePlugin('test-part', self.options,
                                    self.project_options)
 
         os.makedirs(plugin.sourcedir)
@@ -346,18 +324,70 @@ class NodePluginTestCase(NodePluginBaseTestCase):
         self.assertFalse(os.path.exists(plugin._npm_dir))
 
 
+class NodePluginManifestTestCase(NodePluginBaseTestCase):
+
+    scenarios = multiply_scenarios(
+        [
+            ('simple', dict(ls_output=(
+                '{"dependencies": {'
+                '   "testpackage1": {"version": "1.0"},'
+                '   "testpackage2": {"version": "1.2"}}}'))),
+            ('nested', dict(ls_output=(
+                '{"dependencies": {'
+                '   "testpackage1": {'
+                '      "version": "1.0",'
+                '      "dependencies": {'
+                '        "testpackage2": {"version": "1.2"}}}}}'))),
+            ('missing', dict(ls_output=(
+                '{"dependencies": {'
+                '   "testpackage1": {"version": "1.0"},'
+                '   "testpackage2": {"version": "1.2"},'
+                '   "missing": {"noversion": "dummy"}}}')))],
+        [('npm', dict(package_manager='npm')),
+         ('yarn', dict(package_manager='yarn'))])
+
+    def test_get_manifest_with_node_packages(self):
+        self.run_output_mock.return_value = self.ls_output
+
+        self.options.node_package_manager = self.package_manager
+        plugin = nodejs.NodePlugin('test-part', self.options,
+                                   self.project_options)
+        os.makedirs(plugin.sourcedir)
+
+        plugin.build()
+
+        self.assertThat(
+            plugin.get_manifest(), Equals(
+                collections.OrderedDict(
+                    {'node-packages':
+                     ['testpackage1=1.0', 'testpackage2=1.2']})))
+
+
+class NodePluginYarnLockManifestTestCase(NodePluginBaseTestCase):
+
+    def test_get_manifest_with_yarn_lock_file(self):
+        self.options.node_package_manager = 'yarn'
+        plugin = nodejs.NodePlugin('test-part', self.options,
+                                   self.project_options)
+        os.makedirs(plugin.sourcedir)
+        with open(os.path.join(
+                plugin.sourcedir,
+                'yarn.lock'), 'w') as yarn_lock_file:
+            yarn_lock_file.write('test yarn lock contents')
+
+        plugin.build()
+
+        expected_manifest = collections.OrderedDict()
+        expected_manifest['yarn-lock-contents'] = 'test yarn lock contents'
+        expected_manifest['node-packages'] = []
+
+        self.assertThat(plugin.get_manifest(), Equals(expected_manifest))
+
+
 class NodePluginNpmWorkaroundsTestCase(NodePluginBaseTestCase):
 
     def test_build_from_local_fixes_symlinks(self):
-        class Options:
-            source = '.'
-            node_packages = []
-            node_engine = '4'
-            npm_run = []
-            node_package_manager = 'npm'
-            source = '.'
-
-        plugin = nodejs.NodePlugin('test-part', Options(),
+        plugin = nodejs.NodePlugin('test-part', self.options,
                                    self.project_options)
 
         os.makedirs(plugin.sourcedir)
