@@ -69,6 +69,8 @@ class YamlTestCase(YamlBaseTestCase):
         self.addCleanup(patcher.stop)
 
     def test_yaml_aliases(self,):
+        fake_logger = fixtures.FakeLogger(level=logging.WARNING)
+        self.useFixture(fake_logger)
 
         self.make_snapcraft_yaml("""name: test
 version: "1"
@@ -94,6 +96,13 @@ parts:
         self.assertThat(
             c.data['apps']['test']['aliases'], Equals(['test-it', 'testing']))
 
+        # Verify that aliases are properly deprecated
+        self.assertThat(fake_logger.output, Contains(
+            "Aliases are now handled by the store, and shouldn't be declared "
+            'in the snap.'))
+        self.assertThat(fake_logger.output, Contains(
+            "See http://snapcraft.io/docs/deprecation-notices/dn5"))
+
     def test_yaml_aliases_with_duplicates(self):
         fake_logger = fixtures.FakeLogger(level=logging.ERROR)
         self.useFixture(fake_logger)
@@ -420,7 +429,10 @@ parts:
         self.assertThat(
             raised.message,
             Equals("The 'name' property does not match the required "
-                   "schema: 1 is not of type 'string'"))
+                   "schema: 1 is not a valid snap name. Snap names "
+                   "consist of lower-case alphanumeric characters and "
+                   "hyphens. They cannot be all numbers. They also cannot "
+                   "start or end with a hyphen."))
 
     def test_invalid_yaml_invalid_icon_extension(self):
         fake_logger = fixtures.FakeLogger(level=logging.ERROR)
@@ -493,7 +505,10 @@ parts:
         self.assertThat(
             raised.message,
             Equals("The 'name' property does not match the required schema: "
-                   "'myapp@me_1.0' does not match '^[a-z0-9][a-z0-9+-]*$'"))
+                   "'myapp@me_1.0' is not a valid snap name. Snap names "
+                   "consist of lower-case alphanumeric characters and "
+                   "hyphens. They cannot be all numbers. They also cannot "
+                   "start or end with a hyphen."))
 
     def test_invalid_yaml_missing_description(self):
         fake_logger = fixtures.FakeLogger(level=logging.ERROR)
@@ -820,7 +835,35 @@ parts:
         self.assertThat(
             raised.message,
             Equals("The 'version' property does not match the required "
-                   "schema: '' does not match '^[a-zA-Z0-9.+~-]+$'"))
+                   "schema: '' is not a valid snap version. Snap versions "
+                   "consist of upper- and lower-case alphanumeric characters, "
+                   "as well as periods, plus signs, tildes, and hyphens."))
+
+    def test_invalid_yaml_invalid_version(self):
+        fake_logger = fixtures.FakeLogger(level=logging.ERROR)
+        self.useFixture(fake_logger)
+
+        self.make_snapcraft_yaml(dedent("""
+            name: test
+            version: '*'
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              part1:
+                plugin: nil
+        """))
+        raised = self.assertRaises(
+            errors.YamlValidationError,
+            _config.Config)
+
+        self.assertThat(
+            raised.message,
+            Equals("The 'version' property does not match the required "
+                   "schema: '*' is not a valid snap version. Snap versions "
+                   "consist of upper- and lower-case alphanumeric characters, "
+                   "as well as periods, plus signs, tildes, and hyphens."))
 
     def test_invalid_yaml_version_too_long(self):
         fake_logger = fixtures.FakeLogger(level=logging.ERROR)
@@ -1109,8 +1152,50 @@ parts:
 
         self.assertRegex(
             raised.message,
-            "The 'apps' property does not match the required "
-            "schema.*")
+            "The 'apps' property does not match the required schema: .* is "
+            'not a valid app name. App names consist of upper- and lower-case '
+            'alphanumeric characters and hyphens')
+
+
+class InvalidHookNamesYamlTestCase(YamlBaseTestCase):
+
+    scenarios = [
+        (name, dict(name=name)) for
+        name in [
+            '', '-', '--', 'a--a', 'a-', 'a ', ' a', 'a a', '日本語', '한글',
+            'ру́сский язы́к', 'ໄຂ່​ອີ​ສ​ເຕີ້', ':a', 'a:', 'a:a', '_a', 'a_',
+            'a_a', 'Hi',
+        ]
+    ]
+
+    def test_invalid_yaml_invalid_hook_names(self):
+        fake_logger = fixtures.FakeLogger(level=logging.ERROR)
+        self.useFixture(fake_logger)
+
+        self.make_snapcraft_yaml("""name: test
+version: "1"
+summary: test
+description: nothing
+confinement: strict
+grade: stable
+
+hooks:
+  {!r}:
+    plugs: [network]
+
+parts:
+  part1:
+    plugin: nil
+""".format(self.name))
+        raised = self.assertRaises(
+            errors.YamlValidationError,
+            _config.Config)
+
+        self.assertRegex(
+            raised.message,
+            "The 'hooks' property does not match the required schema: .* is "
+            'not a valid hook name. Hook names consist of lower-case '
+            'alphanumeric characters and hyphens')
 
 
 class ValidConfinmentTypesYamlTestCase(YamlBaseTestCase):
@@ -1617,6 +1702,7 @@ parts:
             'snapcraft._options.ProjectOptions.get_core_dynamic_linker')
         mock_core_dynamic_linker = patcher.start()
         mock_core_dynamic_linker.return_value = dynamic_linker
+        self.addCleanup(patcher.stop)
 
         self.make_snapcraft_yaml("""name: test
 version: "1"
@@ -1706,7 +1792,7 @@ parts:
                 stage_dir=self.stage_dir, arch_triplet=self.arch_triplet)
             in environment,
             'Current environment is {!r}'.format(environment))
-        self.assertTrue('PERL5LIB={}/usr/share/perl5/'.format(
+        self.assertTrue('PERL5LIB="{}/usr/share/perl5/"'.format(
             self.stage_dir) in environment)
 
     def test_parts_build_env_ordering_with_deps(self):
@@ -1907,19 +1993,6 @@ class ValidationTestCase(ValidationBaseTestCase):
 
         project_loader.Validator(self.data).validate()
 
-    def test_invalid_part_name_plugin_raises_exception(self):
-        self.data['parts']['plugins'] = {'type': 'go'}
-
-        raised = self.assertRaises(
-            errors.YamlValidationError,
-            project_loader.Validator(self.data).validate)
-
-        expected_message = ("The 'parts' property does not match the "
-                            "required schema: Additional properties are not "
-                            "allowed ('plugins' was unexpected)")
-        self.assertThat(raised.message, Equals(expected_message),
-                        message=self.data)
-
     def test_valid_app_daemons(self):
         self.data['apps'] = {
             'service1': {'command': 'binary1 start', 'daemon': 'simple'},
@@ -2036,7 +2109,10 @@ class RequiredPropertiesTestCase(ValidationBaseTestCase):
 class InvalidNamesTestCase(ValidationBaseTestCase):
 
     scenarios = [(name, dict(name=name)) for
-                 name in ['package@awesome', 'something.another', '_hideme']]
+                 name in [
+                    'package@awesome', 'something.another', '_hideme', '-no',
+                    'a:a', '123'
+    ]]
 
     def test_invalid_names(self):
         data = self.data.copy()
@@ -2046,9 +2122,11 @@ class InvalidNamesTestCase(ValidationBaseTestCase):
             errors.YamlValidationError,
             project_loader.Validator(data).validate)
 
-        expected_message = ("The 'name' property does not match the "
-                            "required schema: '{}' does not match "
-                            "'^[a-z0-9][a-z0-9+-]*$'").format(self.name)
+        expected_message = (
+            "The 'name' property does not match the required schema: '{}' is "
+            "not a valid snap name. Snap names consist of lower-case "
+            "alphanumeric characters and hyphens. They cannot be all numbers. "
+            "They also cannot start or end with a hyphen.").format(self.name)
         self.assertThat(raised.message, Equals(expected_message),
                         message=data)
 
@@ -2116,9 +2194,57 @@ class InvalidAppNamesTestCase(ValidationBaseTestCase):
             project_loader.Validator(data).validate)
 
         expected_message = (
-            "The 'apps' property does not match the required "
-            "schema: Additional properties are not allowed ('{}' "
-            "was unexpected)").format(self.name)
+            "The 'apps' property does not match the required schema: {!r} is "
+            "not a valid app name. App names consist of upper- and lower-case "
+            "alphanumeric characters and hyphens. They cannot start or end "
+            "with a hyphen.").format(self.name)
+        self.assertThat(raised.message, Equals(expected_message),
+                        message=data)
+
+
+class InvalidHookNamesTestCase(ValidationBaseTestCase):
+
+    scenarios = [(name, dict(name=name)) for
+                 name in ['qwe#rty', 'qwe_rty', 'que rty', 'que  rty', 'Hi']]
+
+    def test_invalid_app_names(self):
+        data = self.data.copy()
+        data['hooks'] = {self.name: {'plugs': ['network']}}
+
+        raised = self.assertRaises(
+            errors.YamlValidationError,
+            project_loader.Validator(data).validate)
+
+        expected_message = (
+            "The 'hooks' property does not match the required schema: {!r} is "
+            "not a valid hook name. Hook names consist of lower-case "
+            "alphanumeric characters and hyphens. They cannot start or end "
+            "with a hyphen.").format(
+                self.name)
+        self.assertThat(raised.message, Equals(expected_message),
+                        message=data)
+
+
+class InvalidPartNamesTestCase(ValidationBaseTestCase):
+
+    scenarios = [(name, dict(name=name)) for
+                 name in [
+                    'plugins', 'qwe#rty', 'qwe_rty', 'que rty', 'que  rty']]
+
+    def test_invalid_part_names(self):
+        data = self.data.copy()
+        data['parts'] = {self.name: {'plugin': 'nil'}}
+
+        raised = self.assertRaises(
+            errors.YamlValidationError,
+            project_loader.Validator(data).validate)
+
+        expected_message = (
+            "The 'parts' property does not match the required schema: {!r} is "
+            "not a valid part name. Part names consist of lower-case "
+            "alphanumeric characters, hyphens, plus signs, and forward "
+            "slashes. As a special case, 'plugins' is also not a valid part "
+            "name.").format(self.name)
         self.assertThat(raised.message, Equals(expected_message),
                         message=data)
 
