@@ -17,12 +17,11 @@
 import os
 from unittest import mock
 
+from testtools.matchers import Equals
+
 from snapcraft.internal import sources
 from snapcraft import tests
-from snapcraft.tests.subprocess_utils import (
-    call,
-    call_with_output,
-)
+from snapcraft.tests import fixture_setup
 
 
 class TestBazaar(tests.sources.SourceTestCase):
@@ -93,7 +92,7 @@ class TestBazaar(tests.sources.SourceTestCase):
             'lp:mysource', 'source_dir', source_branch='branch')
 
         expected_message = 'can\'t specify a source-branch for a bzr source'
-        self.assertEqual(raised.message, expected_message)
+        self.assertThat(raised.message, Equals(expected_message))
 
     def test_init_with_source_depth_raises_exception(self):
         raised = self.assertRaises(
@@ -103,7 +102,7 @@ class TestBazaar(tests.sources.SourceTestCase):
 
         expected_message = (
             'can\'t specify source-depth for a bzr source')
-        self.assertEqual(raised.message, expected_message)
+        self.assertThat(raised.message, Equals(expected_message))
 
     def test_init_with_source_tag_and_commit_raises_exception(self):
         raised = self.assertRaises(
@@ -115,7 +114,7 @@ class TestBazaar(tests.sources.SourceTestCase):
         expected_message = (
             'can\'t specify both source-tag and source-commit for '
             'a bzr source')
-        self.assertEqual(raised.message, expected_message)
+        self.assertThat(raised.message, Equals(expected_message))
 
     def test_source_checksum_raises_exception(self):
         raised = self.assertRaises(
@@ -126,7 +125,10 @@ class TestBazaar(tests.sources.SourceTestCase):
 
         expected_message = (
             "can't specify a source-checksum for a bzr source")
-        self.assertEqual(raised.message, expected_message)
+        self.assertThat(raised.message, Equals(expected_message))
+
+    def test_has_source_handler_entry(self):
+        self.assertTrue(sources._source_handler['bzr'] is sources.Bazaar)
 
 
 class BazaarDetailsTestCase(tests.TestCase):
@@ -134,21 +136,10 @@ class BazaarDetailsTestCase(tests.TestCase):
     def setUp(self):
         super().setUp()
         self.working_tree = 'bzr-test'
+        self.bzr_repo = fixture_setup.BzrRepo(self.working_tree)
+        self.useFixture(self.bzr_repo)
         self.source_dir = 'bzr-checkout'
-        os.mkdir(self.working_tree)
         os.mkdir(self.source_dir)
-        os.chdir(self.working_tree)
-        call(['bzr', 'init'])
-        call(['bzr', 'whoami', 'Test User <test.user@example.com>'])
-        with open('testing', 'w') as fp:
-            fp.write('testing')
-        call(['bzr', 'add', 'testing'])
-        call(['bzr', 'commit', '-m', 'testing'])
-        call(['bzr', 'tag', 'test-tag'])
-        self.expected_commit = call_with_output(['bzr', 'revno', '.'])
-        self.expected_tag = 'test-tag'
-
-        os.chdir('..')
 
         self.bzr = sources.Bazaar(self.working_tree, self.source_dir,
                                   silent=True)
@@ -157,13 +148,14 @@ class BazaarDetailsTestCase(tests.TestCase):
         self.source_details = self.bzr._get_source_details()
 
     def test_bzr_details_commit(self):
-        self.assertEqual(
-            self.expected_commit, self.source_details['source-commit'])
+        self.assertThat(
+            self.source_details['source-commit'], Equals(self.bzr_repo.commit))
 
     def test_bzr_details_tag(self):
         self.bzr = sources.Bazaar(self.working_tree, self.source_dir,
-                                  source_tag='test-tag', silent=True)
+                                  source_tag='feature-tag', silent=True)
         self.bzr.pull()
 
         self.source_details = self.bzr._get_source_details()
-        self.assertEqual(self.expected_tag, self.source_details['source-tag'])
+        self.assertThat(
+            self.source_details['source-tag'], Equals('feature-tag'))
