@@ -318,7 +318,7 @@ class GetAccountInformationTestCase(StoreTestCase):
                             'price': None,
                             'since': '2016-12-12T01:01:01Z',
                         },
-                        'ubuntu-core': {
+                        'core': {
                             'snap-id': 'good',
                             'status': 'Approved',
                             'private': False,
@@ -339,6 +339,20 @@ class GetAccountInformationTestCase(StoreTestCase):
                             'price': None,
                             'since': '2016-12-12T01:01:01Z',
                         },
+                        'no-revoked': {
+                            'snap-id': 'no-revoked',
+                            'status': 'Approved',
+                            'private': False,
+                            'price': None,
+                            'since': '2016-12-12T01:01:01Z',
+                        },
+                        'revoked': {
+                            'snap-id': 'revoked',
+                            'status': 'Approved',
+                            'private': False,
+                            'price': None,
+                            'since': '2016-12-12T01:01:01Z',
+                        },
                         'test-snap-with-dev': {
                             'price': None,
                             'private': False,
@@ -374,7 +388,7 @@ class GetAccountInformationTestCase(StoreTestCase):
                             'price': None,
                             'since': '2016-12-12T01:01:01Z',
                         },
-                        'ubuntu-core': {
+                        'core': {
                             'snap-id': 'good',
                             'status': 'Approved',
                             'private': False,
@@ -395,6 +409,20 @@ class GetAccountInformationTestCase(StoreTestCase):
                             'price': None,
                             'since': '2016-12-12T01:01:01Z',
                         },
+                        'no-revoked': {
+                            'snap-id': 'no-revoked',
+                            'status': 'Approved',
+                            'private': False,
+                            'price': None,
+                            'since': '2016-12-12T01:01:01Z',
+                        },
+                        'revoked': {
+                            'snap-id': 'revoked',
+                            'status': 'Approved',
+                            'private': False,
+                            'price': None,
+                            'since': '2016-12-12T01:01:01Z',
+                        },
                         'test-snap-with-dev': {
                             'price': None,
                             'private': False,
@@ -874,6 +902,18 @@ class ReleaseTestCase(StoreTestCase):
             errors.InvalidCredentialsError,
             self.client.release, 'test-snap', '10', ['beta'])
 
+    def test_release_with_invalid_revision(self):
+        self.client.login('dummy', 'test correct password')
+        raised = self.assertRaises(
+            errors.StoreReleaseError,
+            self.client.release,
+            'test-snap-invalid-data', 'notanumber', ['beta'])
+
+        self.assertThat(
+            str(raised),
+            Equals(
+                'invalid-field: The \'revision\' field must be an integer\n'))
+
 
 class CloseChannelsTestCase(StoreTestCase):
 
