@@ -1,3 +1,4 @@
+
 # -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
 #
 # Copyright (C) 2015-2017 Canonical Ltd
@@ -20,6 +21,9 @@ import logging
 import os
 import re
 import shutil
+import subprocess
+import sys
+import textwrap
 from unittest import mock
 
 import fixtures
@@ -37,6 +41,7 @@ import snapcraft
 from snapcraft import storeapi
 from snapcraft.file_utils import calculate_sha3_384
 from snapcraft.internal import errors, pluginhandler, lifecycle
+from snapcraft.internal.lifecycle._runner import _replace_in_part
 from snapcraft import tests
 from snapcraft.tests import fixture_setup
 
@@ -51,16 +56,17 @@ class BaseLifecycleTestCase(tests.TestCase):
         self.project_options = snapcraft.ProjectOptions()
 
     def make_snapcraft_yaml(self, parts, snap_type=''):
-        yaml = """name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-{type}
+        yaml = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            {type}
 
-{parts}
-"""
+            {parts}
+            """)
 
         super().make_snapcraft_yaml(yaml.format(parts=parts, type=snap_type))
 
@@ -82,20 +88,22 @@ class ExecutionTestCase(BaseLifecycleTestCase):
                 self.plugin = Plugin()
 
         part = Part()
-        new_part = lifecycle._replace_in_part(part)
+        new_part = _replace_in_part(part)
 
         self.assertThat(
             new_part.plugin.options.source, Equals(part.plugin.installdir))
 
     def test_exception_when_dependency_is_required(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-    after:
-      - part1
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                    after:
+                      - part1
+                """))
 
         raised = self.assertRaises(
             RuntimeError,
@@ -109,14 +117,16 @@ class ExecutionTestCase(BaseLifecycleTestCase):
                    "prerequisites: 'part1'"))
 
     def test_no_exception_when_dependency_is_required_but_already_staged(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-    after:
-      - part1
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                    after:
+                      - part1
+                """))
 
         def _fake_should_step_run(self, step, force=False):
             return self.name != 'part1'
@@ -137,18 +147,20 @@ class ExecutionTestCase(BaseLifecycleTestCase):
                    'Pulling part2 \n'))
 
     def test_dependency_recursed_correctly(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-    after:
-      - part1
-  part3:
-    plugin: nil
-    after:
-      - part2
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                    after:
+                      - part1
+                  part3:
+                    plugin: nil
+                    after:
+                      - part2
+                """))
 
         snap_info = lifecycle.execute('pull', self.project_options)
 
@@ -179,14 +191,17 @@ class ExecutionTestCase(BaseLifecycleTestCase):
             ))
 
     def test_os_type_returned_by_lifecycle(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-    after:
-      - part1
-""", 'type: os')
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                    after:
+                      - part1
+                """),
+            'type: os')
 
         snap_info = lifecycle.execute('pull', self.project_options)
 
@@ -199,12 +214,14 @@ class ExecutionTestCase(BaseLifecycleTestCase):
         self.assertThat(snap_info, Equals(expected_snap_info))
 
     def test_dirty_prime_reprimes_single_part(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                """))
 
         # Strip it.
         lifecycle.execute('prime', self.project_options)
@@ -248,12 +265,14 @@ class ExecutionTestCase(BaseLifecycleTestCase):
             ]))
 
     def test_dirty_prime_reprimes_multiple_part(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                """))
 
         # Strip it.
         lifecycle.execute('prime', self.project_options)
@@ -298,12 +317,14 @@ class ExecutionTestCase(BaseLifecycleTestCase):
             ]))
 
     def test_dirty_stage_restages_single_part(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                """))
 
         # Stage it.
         lifecycle.execute('stage', self.project_options)
@@ -347,12 +368,14 @@ class ExecutionTestCase(BaseLifecycleTestCase):
             ]))
 
     def test_dirty_stage_restages_multiple_parts(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                """))
 
         # Stage it.
         lifecycle.execute('stage', self.project_options)
@@ -399,13 +422,15 @@ class ExecutionTestCase(BaseLifecycleTestCase):
             ]))
 
     def test_dirty_stage_part_with_built_dependent_raises(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-    after: [part1]
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                    after: [part1]
+                """))
 
         # Stage dependency
         lifecycle.execute('stage', self.project_options, part_names=['part1'])
@@ -449,13 +474,15 @@ class ExecutionTestCase(BaseLifecycleTestCase):
                 "by running:\nsnapcraft clean part2 -s stage\n"))
 
     def test_dirty_stage_part_with_unbuilt_dependent(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-  part2:
-    plugin: nil
-    after: [part1]
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                  part2:
+                    plugin: nil
+                    after: [part1]
+                """))
 
         # Stage dependency (dependent is unbuilt)
         lifecycle.execute('stage', self.project_options, part_names=['part1'])
@@ -490,10 +517,12 @@ class ExecutionTestCase(BaseLifecycleTestCase):
                 'Staging part1 \n'))
 
     def test_dirty_stage_reprimes(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                """))
 
         # Strip it.
         lifecycle.execute('prime', self.project_options)
@@ -523,10 +552,12 @@ class ExecutionTestCase(BaseLifecycleTestCase):
                 'Priming part1 \n'))
 
     def test_dirty_build_raises(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                """))
 
         # Build it.
         lifecycle.execute('build', self.project_options)
@@ -560,10 +591,12 @@ class ExecutionTestCase(BaseLifecycleTestCase):
                 "by running:\nsnapcraft clean part1 -s build\n"))
 
     def test_dirty_pull_raises(self):
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                """))
 
         # Pull it.
         lifecycle.execute('pull', self.project_options)
@@ -599,10 +632,12 @@ class ExecutionTestCase(BaseLifecycleTestCase):
     def test_pull_is_dirty_if_target_arch_changes(
             self, mock_install_build_packages, mock_enable_cross_compilation):
         mock_install_build_packages.return_value = []
-        self.make_snapcraft_yaml("""parts:
-  part1:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                """))
 
         # Pull it with amd64
         lifecycle.execute('pull', snapcraft.ProjectOptions(
@@ -633,23 +668,79 @@ class ExecutionTestCase(BaseLifecycleTestCase):
                 "by running:\nsnapcraft clean part1 -s pull\n"))
 
     def test_prime_excludes_internal_snapcraft_dir(self):
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
         lifecycle.execute('prime', self.project_options)
         self.assertThat(
             os.path.join('prime', 'snap', '.snapcraft'),
             Not(DirExists()))
 
 
+class DirtyBuildScriptletTestCase(BaseLifecycleTestCase):
+
+    scenarios = (
+        ('prepare scriptlet', {'scriptlet': 'prepare'}),
+        ('build scriptlet', {'scriptlet': 'build'}),
+        ('install scriptlet', {'scriptlet': 'install'}),
+    )
+
+    @mock.patch.object(snapcraft.BasePlugin, 'enable_cross_compilation')
+    @mock.patch('snapcraft.repo.Repo.install_build_packages')
+    def test_build_is_dirty_if_scriptlet_changes(
+            self, mock_install_build_packages, mock_enable_cross_compilation):
+        mock_install_build_packages.return_value = []
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                    {}: touch scriptlet
+                """).format(self.scriptlet))
+
+        # Build it
+        lifecycle.execute('build', snapcraft.ProjectOptions())
+
+        # Reset logging since we only care about the following
+        self.fake_logger = fixtures.FakeLogger(level=logging.INFO)
+        self.useFixture(self.fake_logger)
+
+        # Change prepare scriptlet
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  part1:
+                    plugin: nil
+                    {}: touch changed
+                """).format(self.scriptlet))
+
+        # Build it again. Should catch that the scriptlet changed and it needs
+        # to be rebuilt.
+        raised = self.assertRaises(
+            errors.StepOutdatedError,
+            lifecycle.execute, 'build', snapcraft.ProjectOptions())
+
+        self.assertThat(
+            str(raised), Equals(
+                "The 'build' step of 'part1' is out of date:\n"
+                "The {!r} part property appears to have changed.\n"
+                "In order to continue, please clean that part's 'build' step "
+                "by running:\nsnapcraft clean part1 -s build\n".format(
+                    self.scriptlet)))
+
+
 class CleanTestCase(BaseLifecycleTestCase):
 
     def test_clean_removes_global_state(self):
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
         lifecycle.execute('pull', self.project_options)
         lifecycle.clean(self.project_options, parts=None)
         self.assertThat(
@@ -662,10 +753,12 @@ class RecordSnapcraftYamlTestCase(BaseLifecycleTestCase):
     def test_prime_without_build_info_does_not_record(self):
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', None))
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
         lifecycle.execute('prime', self.project_options)
         for file_name in ('snapcraft.yaml', 'manifest.yaml'):
             self.assertThat(
@@ -675,58 +768,186 @@ class RecordSnapcraftYamlTestCase(BaseLifecycleTestCase):
     def test_prime_with_build_info_records_snapcraft_yaml(self):
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', '1'))
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-""", snap_type='type: app')
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """),
+            snap_type='type: app')
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-type: app
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            type: app
 
-parts:
-  test-part:
-    plugin: nil
+            parts:
+              test-part:
+                plugin: nil
 
-""")
+            """)
 
         self.assertThat(
             os.path.join('prime', 'snap', 'snapcraft.yaml'),
             FileContains(expected))
 
 
-class RecordManifestTestCase(BaseLifecycleTestCase):
+class RecordManifestBaseTestCase(BaseLifecycleTestCase):
+
+    def setUp(self):
+        super().setUp()
+        original_check_output = subprocess.check_output
+
+        def fake_uname(cmd, *args, **kwargs):
+            if 'uname' in cmd:
+                return 'Linux test uname 4.10 x86_64'.encode(
+                    sys.getfilesystemencoding())
+            else:
+                return original_check_output(cmd, *args, **kwargs)
+        check_output_patcher = mock.patch(
+            'subprocess.check_output', side_effect=fake_uname)
+        check_output_patcher.start()
+        self.addCleanup(check_output_patcher.stop)
+
+        self.fake_apt_cache = fixture_setup.FakeAptCache()
+        self.useFixture(self.fake_apt_cache)
+
+        self.fake_snapd = fixture_setup.FakeSnapd()
+        self.useFixture(self.fake_snapd)
+        self.fake_snapd.snaps_result = []
+
+
+class RecordManifestTestCase(RecordManifestBaseTestCase):
 
     def test_prime_with_build_info_records_manifest(self):
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', '1'))
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-parts:
-  test-part:
-    build-packages: []
-    plugin: nil
-    prime: []
-    stage: []
-    stage-packages: []
-architectures: [{}]
-build-packages: []
-""".format(self.project_options.deb_arch))
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages: []
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
+        self.assertThat(
+            os.path.join('prime', 'snap', 'manifest.yaml'),
+            FileContains(expected))
+
+    def test_prime_with_installed_snaps(self):
+        self.useFixture(fixtures.EnvironmentVariable(
+            'SNAPCRAFT_BUILD_INFO', '1'))
+        self.fake_snapd.snaps_result = [
+            {'name': 'test-snap-1',
+             'revision': 'test-snap-1-revision'},
+            {'name': 'test-snap-2',
+             'revision': 'test-snap-2-revision'},
+        ]
+
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
+        lifecycle.execute('prime', self.project_options)
+
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages: []
+                installed-snaps:
+                - test-snap-1=test-snap-1-revision
+                - test-snap-2=test-snap-2-revision
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages: []
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
+        self.assertThat(
+            os.path.join('prime', 'snap', 'manifest.yaml'),
+            FileContains(expected))
+
+    def test_prime_with_installed_packages(self):
+        self.useFixture(fixtures.EnvironmentVariable(
+            'SNAPCRAFT_BUILD_INFO', '1'))
+        for name, version in [('test-package1', 'test-version1'),
+                              ('test-package2', 'test-version2')]:
+            self.fake_apt_cache.add_package(
+                fixture_setup.FakeAptCachePackage(
+                    name, version, installed=True))
+
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
+        lifecycle.execute('prime', self.project_options)
+
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages:
+                - test-package1=test-version1
+                - test-package2=test-version2
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages: []
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
         self.assertThat(
             os.path.join('prime', 'snap', 'manifest.yaml'),
             FileContains(expected))
@@ -734,34 +955,45 @@ build-packages: []
     def test_prime_with_stage_packages(self):
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', '1'))
-        self.useFixture(fixture_setup.FakeAptCache([
-            ('test-package1', 'test-version1'),
-            ('test-package2', 'test-version2')]))
+        for name, version in [('test-package1', 'test-version1'),
+                              ('test-package2', 'test-version2')]:
+            self.fake_apt_cache.add_package(
+                fixture_setup.FakeAptCachePackage(name, version))
 
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-    stage-packages: [test-package1=test-version1, test-package2]
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                    stage-packages: [test-package1=test-version1, test-package2]
+                """))  # NOQA
 
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-parts:
-  test-part:
-    build-packages: []
-    plugin: nil
-    prime: []
-    stage: []
-    stage-packages: [test-package1=test-version1, test-package2=test-version2]
-architectures: [{}]
-build-packages: []
-""".format(self.project_options.deb_arch))
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages:
+                - test-package1=test-version1
+                - test-package2=test-version2
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages: []
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
         self.assertThat(
             os.path.join('prime', 'snap', 'manifest.yaml'),
             FileContains(expected))
@@ -770,34 +1002,45 @@ build-packages: []
     def test_prime_with_global_build_packages(self, _):
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', '1'))
-        self.useFixture(fixture_setup.FakeAptCache([
-            ('test-package1', 'test-version1'),
-            ('test-package2', 'test-version2')]))
+        for name, version in [('test-package1', 'test-version1'),
+                              ('test-package2', 'test-version2')]:
+            self.fake_apt_cache.add_package(
+                fixture_setup.FakeAptCachePackage(name, version))
 
-        self.make_snapcraft_yaml("""build-packages: [test-package1=test-version1, test-package2]
-parts:
-  test-part:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                build-packages: [test-package1=test-version1, test-package2]
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
 
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-build-packages: [test-package1=test-version1, test-package2=test-version2]
-parts:
-  test-part:
-    build-packages: []
-    plugin: nil
-    prime: []
-    stage: []
-    stage-packages: []
-architectures: [{}]
-""".format(self.project_options.deb_arch))
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            build-packages:
+            - test-package1=test-version1
+            - test-package2=test-version2
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
         self.assertThat(
             os.path.join('prime', 'snap', 'manifest.yaml'),
             FileContains(expected))
@@ -806,39 +1049,50 @@ architectures: [{}]
     def test_prime_with_source_details(self, _):
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', '1'))
+        self.fake_apt_cache.add_package(
+            fixture_setup.FakeAptCachePackage('git', 'testversion'))
 
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-    source: test-source
-    source-type: git
-    source-commit: test-commit
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                    source: test-source
+                    source-type: git
+                    source-commit: test-commit
+                """))
 
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-parts:
-  test-part:
-    build-packages: []
-    plugin: nil
-    prime: []
-    source: test-source
-    source-branch: ''
-    source-checksum: ''
-    source-commit: test-commit
-    source-tag: ''
-    source-type: git
-    stage: []
-    stage-packages: []
-architectures: [{}]
-build-packages: []
-""".format(self.project_options.deb_arch))
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                source: test-source
+                source-branch: ''
+                source-checksum: ''
+                source-commit: test-commit
+                source-tag: ''
+                source-type: git
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages:
+            - git=testversion
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
         self.assertThat(
             os.path.join('prime', 'snap', 'manifest.yaml'),
             FileContains(expected))
@@ -847,33 +1101,43 @@ build-packages: []
     def test_prime_with_build_package_with_any_architecture(self, _):
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', '1'))
-        self.useFixture(fixture_setup.FakeAptCache([
-            ('test-package', 'test-version')]))
+        self.fake_apt_cache.add_package(fixture_setup.FakeAptCachePackage(
+            'test-package', 'test-version'))
 
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-    build-packages: ['test-package:any']
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                    build-packages: ['test-package:any']
+                """))
 
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-parts:
-  test-part:
-    build-packages: ['test-package:any']
-    plugin: nil
-    prime: []
-    stage: []
-    stage-packages: []
-architectures: [{}]
-build-packages: [test-package=test-version]
-""".format(self.project_options.deb_arch))
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages:
+                - test-package:any
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages:
+            - test-package=test-version
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
         self.assertThat(
             os.path.join('prime', 'snap', 'manifest.yaml'),
             FileContains(expected))
@@ -882,38 +1146,45 @@ build-packages: [test-package=test-version]
     def test_prime_with_virtual_build_package(self, _):
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', '1'))
-        fake_apt_cache = fixture_setup.FakeAptCache()
-        self.useFixture(fake_apt_cache)
-        fake_apt_cache.cache['test-provider-package'] = (
+        self.fake_apt_cache.add_package(
             fixture_setup.FakeAptCachePackage(
-                fake_apt_cache.path,
                 'test-provider-package', 'test-version',
                 provides=['test-virtual-package']))
 
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-    build-packages: ['test-virtual-package']
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                    build-packages: ['test-virtual-package']
+                """))
 
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-parts:
-  test-part:
-    build-packages: [test-virtual-package]
-    plugin: nil
-    prime: []
-    stage: []
-    stage-packages: []
-architectures: [{}]
-build-packages: [test-provider-package=test-version]
-""".format(self.project_options.deb_arch))
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages:
+                - test-virtual-package
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages:
+            - test-provider-package=test-version
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
         self.assertThat(
             os.path.join('prime', 'snap', 'manifest.yaml'),
             FileContains(expected))
@@ -924,35 +1195,107 @@ build-packages: [test-provider-package=test-version]
             'test-plugin-manifest': 'test-value'}
         self.useFixture(fixtures.EnvironmentVariable(
             'SNAPCRAFT_BUILD_INFO', '1'))
-        self.make_snapcraft_yaml("""parts:
-  test-part:
-    plugin: nil
-""")
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-parts:
-  test-part:
-    build-packages: []
-    plugin: nil
-    prime: []
-    stage: []
-    stage-packages: []
-    test-plugin-manifest: test-value
-architectures: [{}]
-build-packages: []
-""".format(self.project_options.deb_arch))
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages: []
+                test-plugin-manifest: test-value
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages: []
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
         self.assertThat(
             os.path.join('prime', 'snap', 'manifest.yaml'),
             FileContains(expected))
 
+    def test_prime_with_image_info_records_manifest(self):
+        self.useFixture(fixtures.EnvironmentVariable(
+            'SNAPCRAFT_BUILD_INFO', '1'))
+        test_image_info = (
+            '{"architecture": "test-architecture", '
+            '"created_at": "test-created-at", '
+            '"fingerprint": "test-fingerprint"}')
+        self.useFixture(fixtures.EnvironmentVariable(
+            'SNAPCRAFT_IMAGE_INFO', test_image_info))
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
+        lifecycle.execute('prime', self.project_options)
 
-class RecordManifestWithDeprecatedSnapKeywordTestCase(BaseLifecycleTestCase):
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime: []
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            image-info:
+              architecture: test-architecture
+              created_at: test-created-at
+              fingerprint: test-fingerprint
+            build-packages: []
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
+        self.assertThat(
+            os.path.join('prime', 'snap', 'manifest.yaml'),
+            FileContains(expected))
+
+    def test_prime_with_invalid_image_info_raises_exception(self):
+        self.useFixture(fixtures.EnvironmentVariable(
+            'SNAPCRAFT_BUILD_INFO', '1'))
+        self.useFixture(fixtures.EnvironmentVariable(
+            'SNAPCRAFT_IMAGE_INFO', 'not-json'))
+        self.make_snapcraft_yaml(
+            textwrap.dedent("""\
+                parts:
+                  test-part:
+                    plugin: nil
+                """))
+        raised = self.assertRaises(
+                errors.InvalidContainerImageInfoError,
+                lifecycle.execute, 'prime', self.project_options)
+        self.assertThat(raised.image_info, Equals('not-json'))
+
+
+class RecordManifestWithDeprecatedSnapKeywordTestCase(
+        RecordManifestBaseTestCase):
 
     scenarios = (
         ('using snap keyword', {'keyword': 'snap'}),
@@ -970,22 +1313,29 @@ class RecordManifestWithDeprecatedSnapKeywordTestCase(BaseLifecycleTestCase):
         self.make_snapcraft_yaml(parts.format(self.keyword))
         lifecycle.execute('prime', self.project_options)
 
-        expected = ("""name: test
-version: 0
-summary: test
-description: test
-confinement: strict
-grade: stable
-parts:
-  test-part:
-    build-packages: []
-    plugin: nil
-    prime: [-*]
-    stage: []
-    stage-packages: []
-architectures: [{}]
-build-packages: []
-""".format(self.project_options.deb_arch))
+        expected = textwrap.dedent("""\
+            name: test
+            version: 0
+            summary: test
+            description: test
+            confinement: strict
+            grade: stable
+            parts:
+              test-part:
+                build-packages: []
+                installed-packages: []
+                installed-snaps: []
+                plugin: nil
+                prime:
+                - -*
+                stage: []
+                stage-packages: []
+                uname: Linux test uname 4.10 x86_64
+            architectures:
+            - {}
+            build-packages: []
+            build-snaps: []
+            """.format(self.project_options.deb_arch))
         self.assertThat(
             os.path.join('prime', 'snap', 'manifest.yaml'),
             FileContains(expected))
@@ -1009,7 +1359,8 @@ class CoreSetupTestCase(tests.TestCase):
         self.addCleanup(patcher.stop)
 
         self.tempdir = os.path.join(self.path, 'tmpdir')
-        patcher = mock.patch('snapcraft.internal.lifecycle.TemporaryDirectory')
+        patcher = mock.patch('snapcraft.internal.lifecycle._runner.'
+                             'TemporaryDirectory')
         self.tempdir_mock = patcher.start()
         self.addCleanup(patcher.stop)
 
@@ -1111,5 +1462,5 @@ class SnapErrorsTestCase(BaseLifecycleTestCase):
             which_mock.return_value = None
             raised = self.assertRaises(
                 errors.MissingCommandError,
-                lifecycle.snap, self.project_options)
+                lifecycle.pack, self.project_options)
         self.assertThat(str(raised), Contains('mksquashfs'))
