@@ -31,6 +31,8 @@ $lxc exec snap-builder -- sh -c "snap install core" || echo "ignored error"
 $lxc file push --recursive $project_path snap-builder/root/
 # TODO use the stable snap once it's published.
 $lxc exec snap-builder -- sh -c "snap install snapcraft --candidate --classic"
-$lxc exec snap-builder -- sh -c "cd snapcraft && /snap/bin/snapcraft"
-
+$lxc exec snap-builder -- sh -c "cd snapcraft && /snap/bin/snapcraft snap --output snapcraft-pr$TRAVIS_PULL_REQUEST.snap"
+# Pull the snap from the container to save it into the cache.
+mkdir -p "$TRAVIS_BUILD_DIR/snaps-cache"
+$lxc file pull "snap-builder/root/snapcraft/snapcraft-pr$TRAVIS_PULL_REQUEST.snap" "$TRAVIS_BUILD_DIR/snaps-cache/"
 $lxc stop snap-builder
